<?php $TRANSLATIONS = array(
"Save" => "Spara",
"Search:" => "Sök:",
"Close" => "Stäng",
"Next" => "Nästa",
"Clear" => "Rensa",
"Saving..." => "Sparar...",
"Failed to save file" => "Det gick inte att spara filen",
"An error occurred!" => "Ett fel uppstod!",
"There were unsaved changes, click here to go back" => "Det finns osparade ändringar, klicka här för att gå tillbaka"
);
